program jcReg2XY
  ! Program to convert regular SEP dataset axes to data
  ! Primary purpose is for plotting regular coordinates on a map
  !
  ! Input:
  !   1) regular history file (need to window out axes you are interested first)
  !    		- eg. n1 needs to be x, n2 needs to be y
  !
  ! Output:
  !   1) regular history file (n1:2, n2: number of data points)
  !
  ! Jason Chang
  ! March 2014


  !================================================
  ! standard initializations
  !================================================
  use sep
  implicit none


  !================================================
  ! declare variable types
  !================================================
  ! history file parameters
  integer                       :: n1,n2    
  real                          :: o1,o2,d1,d2       

  ! program parameters
  integer                       :: ii,jj
  real                          :: x,y


  !================================================
  ! open I/O
  !================================================
  call sep_init()

  ! grab history file parameters
  call from_history('n1',n1,1 )
  call from_history('n2',n2,1 )
  call from_history('o1',o1,0.)
  call from_history('o2',o2,0.)
  call from_history('d1',d1,1.)
  call from_history('d2',d2,1.)

  ! output history file parameters
  call to_history('n1',2    )
  call to_history('n2',n1*n2)
  call to_history('o1',0.   )
  call to_history('o2',1.   )
  call to_history('d1',1.   )
  call to_history('d2',1.   )

  call sep_close()


  !================================================
  ! kernel
  !================================================
  do jj=1,n2

    ! calculate y-coordinate (NS)
    y = o2+(jj-1)*d2

    do ii=1,n1

      ! calculate x-coordinate (EW)
      x = o1+(ii-1)*d1

      ! write out to history file
      call srite('out',x,4)
      call srite('out',y,4)

    end do
  end do


  !================================================
  ! clean up
  !================================================
  call exit(0)


end program
